@@ -88,8 +88,8 @@ def show_new_activity(last_seen=None, cap=1000, template='grouped'):
 
     """
     if not last_seen or last_seen is '':
-        activity_last_seen = datetime.date.today()
-    activities = Activity.objects.filter(timestamp__gte=activity_last_seen)[:cap]
+        last_seen = datetime.date.today()
+    activities = Activity.objects.filter(timestamp__gte=last_seen)[:cap]
 
     if template=='detailed':
         template = 'activity_monitor/includes/detailed.html'
